==> jquery-lte-1.0.1.tgz: package/src/bs/offcanvas.js <==
import {sleep, _boolean, __ as cls, bs} from "../utils/lib.js";

export default (_, bd, options) => {
    const __ = (className, tagName)=> cls.call(_, className, tagName);
    let { title, position, backdrop, keyboard, scroll, parent, background, border } = options;
    const pos = { top: 'top', right: 'end', bottom: 'bottom', left: 'start' }
    const oCanvas = __(`offcanvas jql-offcanvas offcanvas-${pos[position] || 'start'}`);
    const header = _('</>');
    if (title) {
        header.addChild(title).addClass('offcanvas-header').style({ background });
        header.addChild(__(['btn-close', bs.btn, 'text-reset'], 'button')
            .attr({'data-bs-dismiss': "offcanvas" }));
    }
    parent = parent || document.body;
    const body = __('offcanvas-body').style({ background }).addChild(bd);
    oCanvas.addChild([header, body]).appendTo(parent);
    if (background) {
        body.style({ background: '' });
        header.style({ background: '' });
        oCanvas.style({ background });
    }
    if (border)
        oCanvas.style({ border });

    let bsOffcanvas = new bootstrap.Offcanvas(oCanvas.plain(0), {
        backdrop:  _boolean(backdrop),
        keyboard: _boolean(keyboard),
        scroll: _boolean(scroll, false)
    })

    const on = (event, callback) => {
        const cbs = {
            hide: 'hide.bs.offcanvas',
            hidden: 'hidden.bs.offcanvas',
            show: 'show.bs.offcanvas',
            shown: 'shown.bs.offcanvas'
        }
        oCanvas.on(cbs[event], callback);
        return {
            on,
            hide: () => bsOffcanvas.hide(),
            show: () => bsOffcanvas.show()
        };
    }

    const drop = async() => {
        await sleep(500);
        bsOffcanvas.hide();
        oCanvas.drop();
    }

    return {
        on,
        hide(){
            bsOffcanvas.hide();
        },
        show(){
            bsOffcanvas.show();
        },
        toggle(){
            bsOffcanvas.toggle();
        },
        dispose(){
            _(parent).addChild(bd);
            drop();
        },
        drop(){
            drop();
        },
        i: bsOffcanvas
    }
}

==> jquery-lte-1.0.3.tgz: package/src/bs/offcanvas.js <==
import {sleep, _boolean, __ as cls, bs} from "../utils/lib.js";

export default (_, bd, options) => {
    const _bootstrap = typeof bootstrap === 'undefined' ? require('bootstrap') : bootstrap;
    const __ = (className, tagName)=> cls.call(_, className, tagName);
    let { title, position, backdrop, keyboard, scroll, parent, background, border } = options;
    const pos = { top: 'top', right: 'end', bottom: 'bottom', left: 'start' }
    const oCanvas = __(`offcanvas jql-offcanvas offcanvas-${pos[position] || 'start'}`);
    const header = _('</>');
    if (title) {
        header.addChild(title).addClass('offcanvas-header').style({ background });
        header.addChild(__(['btn-close', bs.btn, 'text-reset'], 'button')
            .attr({'data-bs-dismiss': "offcanvas" }));
    }
    parent = parent || document.body;
    const body = __('offcanvas-body').style({ background }).addChild(bd);
    oCanvas.addChild([header, body]).appendTo(parent);
    if (background) {
        body.style({ background: '' });
        header.style({ background: '' });
        oCanvas.style({ background });
    }
    if (border)
        oCanvas.style({ border });

    let bsOffcanvas = new _bootstrap.Offcanvas(oCanvas.plain(0), {
        backdrop:  _boolean(backdrop),
        keyboard: _boolean(keyboard),
        scroll: _boolean(scroll, false)
    })

    const on = (event, callback) => {
        const cbs = {
            hide: 'hide.bs.offcanvas',
            hidden: 'hidden.bs.offcanvas',
            show: 'show.bs.offcanvas',
            shown: 'shown.bs.offcanvas'
        }
        oCanvas.on(cbs[event], callback);
        return {
            on,
            hide: () => bsOffcanvas.hide(),
            show: () => bsOffcanvas.show()
        };
    }

    const drop = async() => {
        await sleep(500);
        bsOffcanvas.hide();
        oCanvas.drop();
    }

    return {
        on,
        hide(){
            bsOffcanvas.hide();
        },
        show(){
            bsOffcanvas.show();
        },
        toggle(){
            bsOffcanvas.toggle();
        },
        dispose(){
            _(parent).addChild(bd);
            drop();
        },
        drop(){
            drop();
        },
        i: bsOffcanvas
    }
}
